{theme=documentation}

\include{"../include.md"}
Getting Started {section-contentlist=False}
===============

# Get started with "Luke, I'm your parser". {section-contentlist=False}
# Lukeparser serves a superset of markdown that includes **customizable commands**, **theme-support** and **live-editing** of documents.

> A long time ago in a galaxy full of markdown parsers...


Quick Start
===========

For a quick look into Lukeparser, just install it using
```bash
pip install lukeparser
```

Test it, by compiling this documentation on your local computer.
```bash
luke --doc
```
Go to [localhost:8080](https://localhost:8080).


Documentation Guide
===================

Please chose depending on your knowledge.  
... And by the way, this documentation is parsed by luke itself. ;)

{.card}
| ---- | --- |
| [Full Markdown Explaination](../02-Components/) | [Just the differences to Plain Markdown](../02-Components/02-Variables-and-Templates.md) |


Digging Deeper
==============
Somewhat deeper topics will include
- The CLI Commands of Luke
- [Using Luke as a Webserver using our Docker Image](../07-Ecosystem)
- [Extending Luke (custom Themes, views or internal-Functions)](../05-Themes-and-Views/)


---

*Version: \version*
